@@ -78,9 +78,6 @@ CREATE TABLE account
   -- graphical representation of the user (avatar) or their photo ID.
   picture_id uuid NULL,
 
-  -- The time when the user's picture was taken.
-  picture_time timestamptz(3) NULL
-
   -- A locale that references the preferred language of the user.  A
   -- locale is expressed by a ISO 639-3 alpha-3 code element, optionally
   -- followed by a dash character "-" and a ISO 3166-1 alpha-2 code.  For
@@ -464,6 +461,9 @@ CREATE TABLE account_picture
   -- picture.
   team_id uuid NULL,
 
+  -- The time when the picture was captured.
+  capture_time timestamptz(3) NULL,
+
   -- The number of pixel columns of the user's original photo image.
   image_width smallint NOT NULL,
 
@@ -504,11 +504,20 @@ CREATE TABLE account_picture
   -- * `AbnormalEyelidOpeningStateException`: An eyelid is widely opened,
   --   narrowed or closed.
   --
-  -- * `UnevenlyOpenEyelidException`: A eye is more opened/closed than the
+  -- * `UnevenlyOpenEyelidException`: An eye is more opened/closed than the
   --   other.
   rejection_exception NULL,
 
-  -- The current status of the picture.
+  -- The current status of the picture:
+  --
+  -- * `deleted`: The photo has been rejected or deleted.
+  --
+  -- * `disabled`: The photo has been temporarily disabled by an
+  --   administrator of the attendant's organization.
+  --
+  -- * `enabled`: The photo has been successfully processed.
+  --
+  -- * `pending`: The photo is being processed.
   object_status text NOT NULL DEFAULT +object-status-pending+,
 
   -- The time when this photo has been registered.
