@@ -105,32 +105,32 @@ class NotificationService(BaseRdbmsService):
         Register a mobile device to the push notification service
 
 
-        :param device_id: Identification of a mobile device that registers
+        @param device_id: Identification of a mobile device that registers
             to push notification service.
 
-        :param device_platform: An item of the enumeration `DevicePlatform`.
+        @param device_platform: An item of the enumeration `DevicePlatform`.
 
-        :param app_id: Identification of the mobile application that
+        @param app_id: Identification of the mobile application that
             registers the mobile device to push notification service.
 
-        :param device_token: Token that identifies the device by the push
+        @param device_token: Token that identifies the device by the push
             notification provider of the device platform.
 
-        :param account_id: Identification of the account of a user who
+        @param account_id: Identification of the account of a user who
             registers his mobile device to push notification service.
 
-        :param connection: An object `RdbmsConnection`.
+        @param connection: An object `RdbmsConnection`.
 
-        :param locale: Preferred language to new messages' textual content in.
+        @param locale: Preferred language to new messages' textual content in.
             This argument is ignored if the mobile device is registered to
             push notification on behalf of a user. Messages will be send in
             the current preferred language of the user.
 
-        :param utc_offset: Difference between the location of the device and
+        @param utc_offset: Difference between the location of the device and
             UTC (Universal Time Coordinated).
 
 
-        :return: An object containing the following attributes:
+        @return: An object containing the following attributes:
 
             * `device_id` (required): Identification of the mobile device that
               registers to push notification service.
@@ -201,19 +201,19 @@ class NotificationService(BaseRdbmsService):
         service
 
 
-        :param device_id: Identification of a mobile device that registered
+        @param device_id: Identification of a mobile device that registered
             to push notification service.
 
-        :param app_id: Identification of the mobile application that
+        @param app_id: Identification of the mobile application that
             registered the mobile device to push notification service.
 
-        :param account_id: Identification of the account of a user who
+        @param account_id: Identification of the account of a user who
             registered his mobile device to push notification service.
 
-        :param connection: An object `RdbmsConnection`.
+        @param connection: An object `RdbmsConnection`.
 
 
-        :return: An object containing the following attributes:
+        @return: An object containing the following attributes:
 
             * `account_id` (optional): Identification of the account of the user
               who registered his mobile device to push notification service.
@@ -299,16 +299,16 @@ class NotificationService(BaseRdbmsService):
         Update the token of a device registered to push notification service
 
 
-        :param registration_id: Identification of the registration of a device
+        @param registration_id: Identification of the registration of a device
             to push notification service
 
-        :param device_token: Token that identifies the device by the push
+        @param device_token: Token that identifies the device by the push
             notification provider of the device platform.
 
-        :param connection: An object `RdbmsConnection` with auto commit.
+        @param connection: An object `RdbmsConnection` with auto commit.
 
 
-        :return: An object containing the following attributes:
+        @return: An object containing the following attributes:
 
             * `device_id` (required): Identification of the mobile device that
               registers to push notification service.
@@ -367,7 +367,7 @@ class NotificationService(BaseRdbmsService):
         by the FCM connection server.
 
 
-        :note: If your organization has a firewall that restricts the traffic
+        @note: If your organization has a firewall that restricts the traffic
             to or from the Internet, you need to configure it to allow
             connectivity with GCM in order for your GCM client apps to receive
             messages. The ports to open are: 5228, 5229, and 5230. GCM
@@ -377,32 +377,32 @@ class NotificationService(BaseRdbmsService):
             IP blocks listed in Google's ASN of 15169.
 
 
-        :param google_api_key: API key saved that gives the application server
+        @param google_api_key: API key saved that gives the application server
             authorized access to Google services.
 
-        :param device_tokens: a list of devices (registration tokens, or IDs as
+        @param device_tokens: a list of devices (registration tokens, or IDs as
             issued by the GCM connection servers to the client application)
              receiving a multicast message. It must contain at least 1 and at
              most 1000 registration IDs.
 
-        :param notification: dictionary of key-value pairs of the notification.
+        @param notification: dictionary of key-value pairs of the notification.
             The key should not be a reserved word ("from" or any word starting
             with "google" or "gcm"). Values in string types are recommended.
             You have to convert values in objects or other non-string data
             types (e.g., integers or booleans) to string.
 
-        :param delay_while_idle: indicate whether the notification should not
+        @param delay_while_idle: indicate whether the notification should not
             be sent until the device becomes active.
 
-        :param gcm_server_http_url: a specific URL to send the message to GCM
+        @param gcm_server_http_url: a specific URL to send the message to GCM
             connection server.
 
-        :param time_to_live: specify how long in seconds the message should be
+        @param time_to_live: specify how long in seconds the message should be
             kept in GCM storage if the device is offline.  The maximum time to
             live supported is 4 weeks.  The default value is 4 weeks.
 
 
-        :return: `None` if the JSON request failed, otherwise a JSON object
+        @return: `None` if the JSON request failed, otherwise a JSON object
             that contains the Downstream HTTP message response body:
 
             * `multicast_id:integer` (required): unique ID (number) identifying
@@ -482,11 +482,11 @@ class NotificationService(BaseRdbmsService):
         Return the properties of the specified notification.
 
 
-        :param notification_id: identification of the notification to return
+        @param notification_id: identification of the notification to return
             the properties.
 
 
-        :return: An object containing the following members:
+        @return: An object containing the following members:
 
             * `creation_time` (required): time when the sender originated
               the notification to the intended recipient.
@@ -569,50 +569,50 @@ class NotificationService(BaseRdbmsService):
         recipient.
 
 
-        :param app_id: Identification of the client application such as a Web,
+        @param app_id: Identification of the client application such as a Web,
             a desktop, or a mobile application, that accesses the service.
 
-        :param recipient_id: Identification of a recipient that may have been
+        @param recipient_id: Identification of a recipient that may have been
             issued notifications, such as, for instance the identification of
             a user account, or the identification of a device, such as an
             International Mobile Equipment Identity (IMEI) for Android device,
             or an alphanumeric string for iOS device.
 
-        :param connection: An object `RdbmsConnection`.  Auto commit MUST be
+        @param connection: An object `RdbmsConnection`.  Auto commit MUST be
             enabled if the argument `mark_read` is equal to `True`.
 
-        :param end_time: Indicate the latest time of submission to return
+        @param end_time: Indicate the latest time of submission to return
             notifications.
 
-        :param include_read: Indicate whether to include notifications that
+        @param include_read: Indicate whether to include notifications that
             have been already read.
 
-        :param limit: Constrain the number of notifications that are returned
+        @param limit: Constrain the number of notifications that are returned
             to the specified number.  Default value is
             `NotificationService.DEFAULT_LIMIT`.  Maximum value is
             is `NotificationService.MAXIMUM_LIMIT`.
 
-        :param mark_read: Indicate whether to mark as read every notification
+        @param mark_read: Indicate whether to mark as read every notification
             that are returned.
 
-        :param notification_types: A list of notification types the recipient
+        @param notification_types: A list of notification types the recipient
             is interested in, or whatever notification if not defined.
 
-        :param offset: Require to skip that many records before beginning to
+        @param offset: Require to skip that many records before beginning to
             return notifications.  Default value is `0`.  If both `offset`
             and `limit` are specified, then `offset` records are skipped
             before starting to count the limit notifications that are
             returned.
 
-        :param sort_order: Ascending order sorts notifications by ascending
+        @param sort_order: Ascending order sorts notifications by ascending
             schedule time, while descending order sorts notifications by
             descending schedule time.
 
-        :param start_time: Indicate the earliest time of submission to return
+        @param start_time: Indicate the earliest time of submission to return
             notifications.
 
 
-        :return: A list of instances containing the following members:
+        @return: A list of instances containing the following members:
 
             * `creation_time` (required): Time when the sender originated the
               notification to the intended recipient.
@@ -751,7 +751,7 @@ class NotificationService(BaseRdbmsService):
         platform.
 
 
-        :note: the function registers the device on behalf of the application
+        @note: the function registers the device on behalf of the application
             identification of the server platform, not the identification of
             the client application itself.  An instance of a server platform
             is specific to a particular service to which client applications,
@@ -763,10 +763,10 @@ class NotificationService(BaseRdbmsService):
         @todo: the argument "topics" is not used at the moment.
 
 
-        :param app_id: Identification of the client application such as a Web,
+        @param app_id: Identification of the client application such as a Web,
             a desktop, or a mobile application, that accesses the service.
 
-        :param device_id: Identification of the device, which depends on the
+        @param device_id: Identification of the device, which depends on the
             device platform:
 
             * Android: International Mobile Equipment Identity (IMEI) number
@@ -779,7 +779,7 @@ class NotificationService(BaseRdbmsService):
               solution aimed at solving the main privacy issues that caused
               Apple to deprecate UDIDs.
 
-        :param device_token: Token that identifies the device by the push
+        @param device_token: Token that identifies the device by the push
             notification provider of the device platform.
 
             * Android: token identifying the device to push the notification
@@ -804,7 +804,7 @@ class NotificationService(BaseRdbmsService):
               as the device UDID returned by the `uniqueIdentifier` property
               of `UIDevice`.
 
-        :param device_platform: Indicate the platform of the end user's mobile
+        @param device_platform: Indicate the platform of the end user's mobile
             device:
 
             * `ios`: Apple iOS
@@ -813,13 +813,13 @@ class NotificationService(BaseRdbmsService):
 
             * `windows`: Windows Phone
 
-        :param account_id: Identification of the account of the user on behalf
+        @param account_id: Identification of the account of the user on behalf
             of whom the device is registered to receive push notification
             messages.
 
-        :param connection: An object `RdbmsConnection` with auto commit.
+        @param connection: An object `RdbmsConnection` with auto commit.
 
-        :param locale: Represent the language that the end user prefers
+        @param locale: Represent the language that the end user prefers
             receiving new content in.  A locale corresponds to a tag
             respecting RFC 4646, expressed by a ISO 639-3 alpha-3 code
             element, optionally followed by a dash character `-` and a ISO
@@ -828,19 +828,19 @@ class NotificationService(BaseRdbmsService):
             argument is not specified, the locale corresponds to the preferred
             language that the user has defined in his profile.
 
-        :param topics: A list of keywords representing topics the end user is
+        @param topics: A list of keywords representing topics the end user is
             interested in to be pushed new content whenever related to one of
             those topics.  The list of supported keywords is specific to the
             publisher service of the client application and as such the
             developer of the client application has to refer to the technical
             documentation of the publisher service.
 
-        :param utc_offset: Difference between the location of the device and
+        @param utc_offset: Difference between the location of the device and
             UTC (Universal Time Coordinated).  UTC is also known as GMT or
             Greenwich Mean Time or Zulu Time.
 
 
-        :return: An object containing the following attributes:
+        @return: An object containing the following attributes:
 
             * `device_id` (required): Identification of the mobile device that
               registers to push notification service.
@@ -908,28 +908,28 @@ class NotificationService(BaseRdbmsService):
         device may be unavailable (e.g., turned off, no network coverage).
 
 
-        :param app_id: identification of the client application such as a Web,
+        @param app_id: identification of the client application such as a Web,
             a desktop, or a mobile application, that accesses the service.
 
-        :param notification_type: type of the notification to be sent, such as
+        @param notification_type: type of the notification to be sent, such as
             for instance `on_something_happened`.
 
-        :param connection: a `RdbmsConnection` instance to be used
+        @param connection: a `RdbmsConnection` instance to be used
             supporting the Python clause `with ...:`.
 
-        :param recipient_ids: identification of a recipient, or a list of
+        @param recipient_ids: identification of a recipient, or a list of
             identifications of recipients, to send the notification to.
 
-        :param team_id: identification of a team to send the notification to
+        @param team_id: identification of a team to send the notification to
             all the members.
 
-        :param if_not_exists: indicate whether the notification needs to be
+        @param if_not_exists: indicate whether the notification needs to be
             ignored for a particular recipient if the latter already received
             a notification of the same type that the recipient has not yet
             read.  The function doesn't check whether a previous notification
             of the same type may have a different payload.
 
-        :param lifespan: period of time expressed in seconds during which
+        @param lifespan: period of time expressed in seconds during which
             information of the notification reasonably may be expected
             usefully to inform an action or interest of the intended
             recipients.  After the lifespan expires, provision of the
@@ -937,7 +937,7 @@ class NotificationService(BaseRdbmsService):
             and its content may be deleted.  The maximum lifespan is
             `NotificationService.MAXIMUM_LIFESPAN`.
 
-        :param notification_mode: an item of the enumeration `NotificationMode`
+        @param notification_mode: an item of the enumeration `NotificationMode`
             to indicate the mode to deliver this notification to the
             recipients:
 
@@ -952,18 +952,18 @@ class NotificationService(BaseRdbmsService):
               information is initiated by the publisher or server platform and
               pushed out to the receiver or client application.
 
-        :param payload: any arbitrary JSON expression added by the sender to
+        @param payload: any arbitrary JSON expression added by the sender to
             provide information about the context of this notification.
 
-        :param sender_id: identification of the sender on behalf whom the
+        @param sender_id: identification of the sender on behalf whom the
             notification is sent to the recipients.
 
-        :param schedule_time: Time when this notification needs to be sent to
+        @param schedule_time: Time when this notification needs to be sent to
             the intended recipient.  The notification is not visible to the
             intended recipient prior to this time.  If not specified, the
             notification is sent as soon as possible.
 
-        :param recipient_timezones: dictionary of time zones of the intended
+        @param recipient_timezones: dictionary of time zones of the intended
             recipients for which the schedule time is expected to be in their
             local time.  The key corresponds to the identification of an
             intended recipient, and the value corresponds to time zone of this
@@ -984,7 +984,7 @@ class NotificationService(BaseRdbmsService):
             recipient is then `2013-12-20 08:00:00+07`
 
 
-        :return: a list of instances containing the following members:
+        @return: a list of instances containing the following members:
 
             * `notification_id`: Identification of the notification sent to a
               particular recipient.
@@ -1110,10 +1110,10 @@ class NotificationService(BaseRdbmsService):
         platform.
 
 
-        :param app_id: identification of the client application such as a Web,
+        @param app_id: identification of the client application such as a Web,
             a desktop, or a mobile application, that accesses the service.
 
-        :param device_id: identification of the device, which depends on the
+        @param device_id: identification of the device, which depends on the
             device platform:
 
             * Android: International Mobile Equipment Identity (IMEI) number
@@ -1126,7 +1126,7 @@ class NotificationService(BaseRdbmsService):
               solution aimed at solving the main privacy issues that caused
               Apple to deprecate UDIDs.
 
-        :param account_id: identification of the account of the user on behalf
+        @param account_id: identification of the account of the user on behalf
             of whom the device is unregistered from receiving push
             notification messages.
         """
@@ -1159,15 +1159,15 @@ class NotificationService(BaseRdbmsService):
 #     Flush all the notifications originated from the given client
 #     application that were sent to the specified user.
 #
-#     :param app_id: identification of the client application such as a Web,
+#     @param app_id: identification of the client application such as a Web,
 #         a desktop, or a mobile application, that accesses the service.
-#     :param account_id: identification of the account of the user to flush
+#     @param account_id: identification of the account of the user to flush
 #         all the notifications he receives from the given application.
-#     :param service_name: code name of the service that originated the
+#     @param service_name: code name of the service that originated the
 #         notifications to flush.  By convention, the code name of the
 #         service corresponds to the Python class of this service (cf.
 #         `self.__class__.__name__`).
-#     :param notification_types: a list of types of the notifications to
+#     @param notification_types: a list of types of the notifications to
 #         flush.  If no list is provided, the function flushes all the
 #         notifications that the client application posted to the user.
 #     """
@@ -1205,16 +1205,16 @@ class NotificationService(BaseRdbmsService):
 #     Update the read mark of a list of notifications sent to the specified
 #     user.
 #
-#     :param app_id: identification of the client application such as a Web,
+#     @param app_id: identification of the client application such as a Web,
 #            a desktop, or a mobile application, that accesses the service.
 #
-#     :param account_id: identification of the account of a user whom the
+#     @param account_id: identification of the account of a user whom the
 #            specified notifications have been sent to.
 #
-#     :param notification_ids: a list of notification to mark as read or
+#     @param notification_ids: a list of notification to mark as read or
 #            unread.
 #
-#     :param mark_read: indicate whether to mark as read the specified
+#     @param mark_read: indicate whether to mark as read the specified
 #         notifications.
 #     """
 #     if notification_ids is None:
@@ -1264,32 +1264,32 @@ class NotificationService(BaseRdbmsService):
 # @warning: this function is for internal usage only; it MUST not be
 #     surfaced to any client applications through a RESTful API.
 #
-# :param app_id: identification of the client application such as a Web,
+# @param app_id: identification of the client application such as a Web,
 #     a desktop, or a mobile application, that accesses the service.
-# :param notification_type: type of the notification such as
+# @param notification_type: type of the notification such as
 #     `on_something_happened`.
-# :param notification_mode:
+# @param notification_mode:
 #
-# :param account_ids: list of account identifications of users to send
+# @param account_ids: list of account identifications of users to send
 #     the notification to.
-# :param device_ids: list of identifications of devices to send the
+# @param device_ids: list of identifications of devices to send the
 #     notification to.
 #
-# :param payload: content of the notification to send to the recipients.
+# @param payload: content of the notification to send to the recipients.
 #     The content could be a simple string caption, or an object which
 #     the function converts its JSON expression.into a string
 #     representation.
-# :param lifespan: duration in minutes the notification lives before it
+# @param lifespan: duration in minutes the notification lives before it
 #     is deleted.  If not defined, the notification persists forever as
 #     long as it is not read.
-# :param topics: a list of keywords indicating the subjects of this
+# @param topics: a list of keywords indicating the subjects of this
 #     notifications.  Only the subscribers who have registered for these
 #     topics will be pushed this notification.
 #
-# :param schedule_time: schedule the notification to automatically be
+# @param schedule_time: schedule the notification to automatically be
 #     sent later at the given time.  If not specified, the notification
 #     is sent as soon as possible.
-# :param use_local_time: indicate whether the schedule time is assumed
+# @param use_local_time: indicate whether the schedule time is assumed
 #     to be in local time of a particular device.  If so, the
 #     `schedule_time` is converted to UTC, and the time zone
 #     information is then stripped out to provide a local time.  For
@@ -1299,7 +1299,7 @@ class NotificationService(BaseRdbmsService):
 #     for the region, i.e., time zone, of a particular device to send
 #     the notification to.
 #
-# :param is_broadcast: indicate whether the notification needs to be
+# @param is_broadcast: indicate whether the notification needs to be
 #     sent to every users who subscribed for receiving notification from
 #     this application (determined by `app_id`), or more generally
 #     from the product this application belongs to (if the argument
@@ -1315,7 +1315,7 @@ class NotificationService(BaseRdbmsService):
 #         # If the payload of the message is not a simple type, convert it to a
 #         # string representation of a JSON expression.
 #         #
-#         # :note: `basestring` includes `str` and `unicode`.
+#         # @note: `basestring` includes `str` and `unicode`.
 #         if payload and not isinstance(payload,  (basestring, int, long, float, complex)):
 #             payload = obj.jsonify(payload)
 
@@ -1336,36 +1336,36 @@ class NotificationService(BaseRdbmsService):
 #     device may be unavailable (e.g., turned off, no network coverage).
 #
 #
-#     :param app_id: identification of the client application such as a Web,
+#     @param app_id: identification of the client application such as a Web,
 #         a desktop, or a mobile application, that accesses the service.
 #
-#     :param notification_type: type of the notification to be sent, such as
+#     @param notification_type: type of the notification to be sent, such as
 #         for instance `on_something_happened`.
 #
-#     :param device_ids: identification of the device, or a list of
+#     @param device_ids: identification of the device, or a list of
 #         identifications of devices, to send the notification to.
 #
-#     :param if_not_exists: indicate whether the notification needs to be
+#     @param if_not_exists: indicate whether the notification needs to be
 #         ignored for a particular device if the latter already received a
 #         notification of the same type that the device has not yet read.
 #         The function doesn't check whether a previous notification of the
 #         same type may have a different payload.
 #
-#     :param lifespan: period of time expressed in seconds during which
+#     @param lifespan: period of time expressed in seconds during which
 #         information of the notification reasonably may be expected
 #         usefully to inform an action or interest of the intended devices.
 #         After the lifespan expires, provision of the notification to the
 #         devices may be prevented; the notification and its content may be
 #         deleted.  The maximum lifespan is `NotificationService.MAXIMUM_LIFESPAN`.
 #
-#     :param payload: any arbitrary JSON expression added by the sender to
+#     @param payload: any arbitrary JSON expression added by the sender to
 #         provide information about the context of this notification.
 #
-#     :param sender_id: identification of the sender on behalf whom the
+#     @param sender_id: identification of the sender on behalf whom the
 #         notification is sent to the devices.
 #
 #
-#     :return: a list of instances containing the following members:
+#     @return: a list of instances containing the following members:
 #
 #         * `creation_time` (required): time when the notification was
 #           registered to the platform.
@@ -1495,4 +1495,3 @@ class NotificationService(BaseRdbmsService):
 #
 #         return [ row.get_object({ 'notification_id': cast.string_to_uuid })
 #                 for row in cursor.fetch_all() ]
-
